# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.cluster
from kaistack.clients.openapi_clients.cluster.models.codegen_get_cluster_config_response import CodegenGetClusterConfigResponse  # noqa: E501
from kaistack.clients.openapi_clients.cluster.rest import ApiException

class TestCodegenGetClusterConfigResponse(unittest.TestCase):
    """CodegenGetClusterConfigResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetClusterConfigResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.cluster.models.codegen_get_cluster_config_response.CodegenGetClusterConfigResponse()  # noqa: E501
        if include_optional :
            return CodegenGetClusterConfigResponse(
                config = kaistack.clients.openapi_clients.cluster.models.codegen_cluster_config.codegenClusterConfig(
                    artifacts_store = kaistack.clients.openapi_clients.cluster.models.codegen_artifacts_store_config.codegenArtifactsStoreConfig(
                        bucket = '0', 
                        key_prefix = '0', ), )
            )
        else :
            return CodegenGetClusterConfigResponse(
        )

    def testCodegenGetClusterConfigResponse(self):
        """Test CodegenGetClusterConfigResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
